<?php

/**
 * Get configuration settings
 *
 * Example
 *
 * ```php
 * config('key'); // get by key
 * config(['key1', 'key2', 'key3'); // get deep value
 * config(); // get all values
 * ```
 * @param mixed $params
 * @return mixed
 */
function config($params = null)
{
    static $config = null;

    if ($config === null) {
        $config = require_once __DIR__ . '/config.php';
    }

    if ($params === null) {
        return $config;
    }

    if (is_array($params)) {
        $cursor = $config;
        foreach ($params as $param) {
            if (!is_array($cursor) || !array_key_exists($param, $cursor)) {
                return null;
            }
            $cursor = $cursor[$param];
        }
        return $cursor;
    }

    return isset($config[$params]) ? $config[$params] : null;
}
